 /**
 * Copyright (c) 2020-2020 yann
 * Licensed under the Apache License, Version 1.0 (the "License");
 */
 package com.inet.ailink.receiver.service.impl;

 import com.inet.ailink.receiver.common.enums.StatusCode;
 import com.inet.ailink.receiver.common.utils.Base64TeaUitls;
 import com.inet.ailink.receiver.common.vo.Response;
 import com.inet.ailink.receiver.entity.BloodPressure;
 import com.inet.ailink.receiver.entity.Device;
 import com.inet.ailink.receiver.mapper.IBloodPressureDao;
 import com.inet.ailink.receiver.mapper.ISysDeviceInfoDao;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Service;
 import org.springframework.transaction.annotation.Transactional;

 import javax.servlet.http.HttpServletRequest;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;

 @Service
 @Transactional(rollbackFor=Exception.class)
 public class BloodPressureServiceImpl extends  BaseServiceImpl<IBloodPressureDao,BloodPressure>
 {

     @Autowired
     IBloodPressureDao bloodPressureDao;

     @Autowired
     ISysDeviceInfoDao deviceInfoDao;

     @Override
     protected IBloodPressureDao getEntityDao() {
         // TODO Auto-generated method stub
         return bloodPressureDao;
     }

     public Response<Object> saveOrUpdateBloodPressure(byte[] paramsByte,HttpServletRequest request) {
         Response<Object> result = new Response<Object>();
         try {
         //解析数据
         //设备ID【0-3】
         Integer deviceId = Integer.parseInt(Base64TeaUitls.getLowConactHighEndForLong(0, 3, paramsByte)+"");
         String	deviceId2 = Base64TeaUitls.getStartToEndForHex(0, 3, paramsByte);
         //舒张压【4-5】
         String dia = Base64TeaUitls.getLowConactHighEndForInt(4, 5, paramsByte);
         //收缩压【6-7】
         String sys = Base64TeaUitls.getLowConactHighEndForInt(6, 7, paramsByte);
         //心率【8】
         String pul = Base64TeaUitls.getStartToEndForInt(8, 8, paramsByte);
         //单位【9】；0：mmhg；1：kPa
         String unit = Base64TeaUitls.getStartToEndForInt(9, 9, paramsByte);
         //小数点【10】：0：无小数点；1：1位小数点；2：2位小数点；N：N位小数点
         String point = Base64TeaUitls.getStartToEndForInt(10, 10, paramsByte);

         BloodPressure bloodPressure = new BloodPressure();
         //设置基础数据
         bloodPressure.setDeviceId(deviceId);
         bloodPressure.setDia(dia);
         bloodPressure.setSys(sys);
         bloodPressure.setPul(pul);
         bloodPressure.setUnit(Integer.parseInt(unit));
         bloodPressure.setPoint(Integer.parseInt(point));
         bloodPressure.setConfirmStatus(0);
         //设置默认值；和蓝牙统一
         bloodPressure.setMedicine(-1);
         bloodPressure.setFeel(-1);
         //设备未上传时间，以本地时间为准
         bloodPressure.setCreateTimeLong(new Date().getTime());
         bloodPressure.setUploadTime(new Date());
         //查询该设备是否有绑定用户，具体实现根据业务实现
         List<Integer> appUserIds = new ArrayList<Integer>();
         //设置其他值
         if(appUserIds != null && appUserIds.size()>0){
             for(Integer appUserId:appUserIds){
                 bloodPressure.setAppUserId(appUserId);
                 //保存数据
                 if(bloodPressureDao.insert(bloodPressure) > 0){
                     result.setStatus(StatusCode.SUCCESS.getCode());
                     result.setData(bloodPressure.getId());
                     //推送给APP
                     //aliyunPushService.pushForBloodPressure(bloodPressure);
                 }else{
                     result.setStatus(StatusCode.FAIL.getCode());
                 }
             }
         }else{
             bloodPressure.setAppUserId(0);
             bloodPressure.setRemark("没有绑定用户");
             bloodPressureDao.insert(bloodPressure);
             result.setStatus(StatusCode.SUCCESS.getCode());
         }
         } catch (Exception e) {
             e.printStackTrace();
             result.setStatus(StatusCode.PARAMS_dECRYPT_ERROR.getCode());
         }
         return result;
     }
 }